## 24.0.0.20240423 (2024-04-23)

Bump boltons to 24.0.* (#11804)

## 23.1.0.20240331 (2024-03-31)

Remove bare Incomplete annotations in third-party stubs (#11671)

## 23.1.0.20240310 (2024-03-10)

Bump mypy to 1.9, add to json.encoder, small fixups (#11549)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 23.1.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 23.1.0.0 (2023-11-30)

Bump boltons to 23.1.* (#11083)

## 23.0.0.2 (2023-11-22)

third-party stubs: Add several missing `__del__` methods (#11054)

## 23.0.0.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 23.0.0.0 (2023-06-07)

add boltons (#8892)

Co-authored-by: Andrey Maslennikov <andrew.maslennikov@gmail.com>
Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

